@@ -127,10 +127,10 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mUi->mSolveButton, &QPushButton::clicked, this,
             &IncidenceAttendee::slotSolveConflictPressed);
     /* Added as part of kolab/issue2297, which is currently under review
-    connect(mUi->mOrganizerCombo, QOverload<const QString &>::of(&KComboBox::activated),
+    connect(mUi->mOrganizerCombo, QOverload<const QString &>::of(&QComboBox::activated),
             this, &IncidenceAttendee::slotOrganizerChanged);
     */
-    connect(mUi->mOrganizerCombo, QOverload<int>::of(&KComboBox::currentIndexChanged),
+    connect(mUi->mOrganizerCombo, QOverload<int>::of(&QComboBox::currentIndexChanged),
             this, &IncidenceAttendee::checkDirtyStatus);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
@@ -145,15 +145,15 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mConflictResolver, &ConflictResolver::conflictsDetected, this,
             &IncidenceAttendee::slotUpdateConflictLabel);
 
-    connect(mConflictResolver->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(slotFreeBusyAdded(QModelIndex,int,int)));
+    connect(mConflictResolver->model(), &QAbstractItemModel::rowsInserted,
+            this, &IncidenceAttendee::slotFreeBusyAdded);
     connect(mConflictResolver->model(), SIGNAL(layoutChanged()), SLOT(updateFBStatus()));
-    connect(mConflictResolver->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            SLOT(slotFreeBusyChanged(QModelIndex,QModelIndex)));
+    connect(mConflictResolver->model(), &QAbstractItemModel::dataChanged,
+            this, &IncidenceAttendee::slotFreeBusyChanged);
 
     slotUpdateConflictLabel(0);   //initialize label
 
-    // confict resolver (should show also resources)
+    // conflict resolver (should show also resources)
     connect(mDataModel, &AttendeeTableModel::layoutChanged, this,
             &IncidenceAttendee::slotConflictResolverLayoutChanged);
     connect(mDataModel, &AttendeeTableModel::rowsAboutToBeRemoved, this,
@@ -650,8 +650,8 @@ void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee::Ptr &attendee,
         if (fb) {
             KCalCore::Period::List busyPeriods = fb->busyPeriods();
             for (auto it = busyPeriods.begin(); it != busyPeriods.end(); ++it) {
-                // periods started before and laping into the incidence (s < startTime && e >= startTime)
-                // periods starting in the time of incidende (s >= startTime && s <= endTime)
+                // periods started before and lapping into the incidence (s < startTime && e >= startTime)
+                // periods starting in the time of incidence (s >= startTime && s <= endTime)
                 if (((*it).start() < startTime && (*it).end() > startTime)
                     || ((*it).start() >= startTime && (*it).start() <= endTime)) {
                     switch (attendee->status()) {
