@@ -43,15 +43,14 @@ public:
     using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
 
-    explicit IncidenceResource(IncidenceAttendee *mIeAttendee, IncidenceDateTime *dateTime,
-                               Ui::EventOrTodoDesktop *ui);
+    explicit IncidenceResource(IncidenceAttendee *mIeAttendee, IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui);
 
     void load(const KCalCore::Incidence::Ptr &incidence) override;
     void save(const KCalCore::Incidence::Ptr &incidence) override;
     bool isDirty() const override;
 
-    /** resturn the count of resources */
-    int resourceCount() const;
+    /** return the count of resources */
+    Q_REQUIRED_RESULT int resourceCount() const;
 
 Q_SIGNALS:
     /** is emitted it the count of the resources is changed.
