@@ -29,9 +29,7 @@
 
 using namespace IncidenceEditorNG;
 
-OpenComposerJob::OpenComposerJob(QObject *parent, const QString &to, const QString &cc,
-                                 const QString &bcc, const KMime::Message::Ptr &message,
-                                 const KIdentityManagement::Identity &identity)
+OpenComposerJob::OpenComposerJob(QObject *parent, const QString &to, const QString &cc, const QString &bcc, const KMime::Message::Ptr &message, const KIdentityManagement::Identity &identity)
     : KJob(parent)
     , mTo(to)
     , mCc(cc)
@@ -54,11 +52,7 @@ void OpenComposerJob::start()
     mSuccess = false;
     if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral(
                                                                            "org.kde.kmail"))) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
         QMetaObject::invokeMethod(this, &OpenComposerJob::processMail, Qt::QueuedConnection);
-#else
-        QMetaObject::invokeMethod(this, "processMail", Qt::QueuedConnection);
-#endif
     }
     //Check if Kontact is already running and if not ...
     int result = KDBusServiceStarter::self()->findServiceFor(QStringLiteral("DBUS/Mailer"),
@@ -95,8 +89,7 @@ void OpenComposerJob::timeout()
     }
 }
 
-void OpenComposerJob::slotServiceOwnerChanged(const QString &name, const QString &oldOwner,
-                                              const QString &newOwner)
+void OpenComposerJob::slotServiceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner)
 {
     Q_UNUSED(oldOwner);
     if (name == QLatin1String("org.kde.kmail") && !newOwner.isEmpty()) {
